@@ -1,7 +1,7 @@
 import functools
 import logging
 import time
-from retry_wraps import retry_wraps as r
+from pubhelper.retry_wraps import retry_wraps as r
 
 
 def timethis(fn=None, *, logger=None):
